@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Config::Entities;
-$Config::Entities::VERSION = '0.03';
+$Config::Entities::VERSION = '1.00';
 # ABSTRACT: An multi-level overridable perl based configuration module
 # PODNAME: Config::Entities
 
@@ -79,6 +79,12 @@ sub _init {
         }
     }
 
+    if ( $options->{entity} ) {
+        foreach my $key ( keys( %{ $options->{entity} } ) ) {
+            _merge( $self, $key, $options->{entity}{$key} );
+        }
+    }
+
     if ( scalar(@entities_roots) ) {
         find(
             sub {
@@ -164,7 +170,7 @@ Config::Entities - An multi-level overridable perl based configuration module
 
 =head1 VERSION
 
-version 0.03
+version 1.00
 
 =head1 SYNOPSIS
 
@@ -281,6 +287,11 @@ available options are:
 
 =over 4
 
+=item entity
+
+A hashref containing configuration.  Will be overriden by the contents of any
+C<$entities_root_dir>'s that are passed in.
+
 =item properties
 
 Properties to be loaded into C<Config::Entities::properties>.  Will override any
